/*
    JPC: A x86 PC Hardware Emulator for a pure Java Virtual Machine
    Release Version 2.0

    A project from the Physics Dept, The University of Oxford

    Copyright (C) 2007 Isis Innovation Limited

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License version 2 as published by
    the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
    Details (including contact information) can be found at: 

    www.physics.ox.ac.uk/jpc
*/


package org.jpc.emulator.processor;

import org.jpc.emulator.memory.*;
import org.jpc.emulator.*;

public interface Segment extends Hibernatable
{
    public boolean isPresent();

    public void setAddressSpace(AddressSpace memory);

    public int getType();

    public int getSelector();

    public int getLimit();

    public int getBase();

    public boolean getDefaultSizeFlag();
    
    public int getRPL();

    public void setRPL(int cpl);
    
    public int getDPL();
    
    public boolean setSelector(int selector);

    public void checkAddress(int offset) throws ProcessorException;

    public int translateAddressRead(int offset);

    public int translateAddressWrite(int offset);

    public byte getByte(int offset);
    
    public short getWord(int offset);

    public int getDoubleWord(int offset);

    public long getQuadWord(int offset);
    
    public void setByte(int offset, byte data);

    public void setWord(int offset, short data);

    public void setDoubleWord(int offset, int data);

    public void setQuadWord(int offset, long data);
}
